@@ -7,6 +7,9 @@
 #include "pyobjc-api.h"
 
 #import <ApplicationServices/ApplicationServices.h>
+#if PyObjC_BUILD_RELEASE > 1008
+#import <CoreGraphics/CoreGraphics.h>
+#endif
 
 
 /* 
@@ -24,9 +27,16 @@ m_CGDataConsumerPutBytesCallback(void* _info, const void* buffer, size_t count)
 	PyGILState_STATE   state = PyGILState_Ensure();
 
 	PyObject* result = PyObject_CallFunction(
-			PyTuple_GET_ITEM(info, 0), "Os#l",
-			PyTuple_GET_ITEM(info, 2), buffer, count, count);
+			PyTuple_GET_ITEM(info, 0), 
+#if PY_MAJOR_VERSION == 2
+			"Os#l",
+#else
+			"Oy#l",
+#endif
+			PyTuple_GET_ITEM(info, 2), buffer, (Py_ssize_t)count, (Py_ssize_t)count);
 	if (result == NULL) {
+		printf("%s\n", PyObject_REPR(PyTuple_GET_ITEM(info, 2)));
+		printf("%p\n", buffer);
 		PyObjCErr_ToObjCWithGILState(&state);
 	}
 
@@ -217,6 +227,8 @@ m_CGDataProviderGetBytesCallback(
 	return c_result;
 }
 
+#if PyObjC_BUILD_RELEASE < 1008
+
 static void 
 m_CGDataProviderSkipBytesCallback(void* _info, size_t count)
 {
@@ -234,6 +246,8 @@ m_CGDataProviderSkipBytesCallback(void* _info, size_t count)
 	PyGILState_Release(state);
 }
 
+#endif
+
 static void 
 m_CGDataProviderRewindCallback(void* _info)
 {
@@ -273,13 +287,16 @@ m_CGDataProviderReleaseInfoCallback(void* _info)
 	PyGILState_Release(state);
 }
 
+#if PyObjC_BUILD_RELEASE < 1008
 static CGDataProviderCallbacks m_CGDataProviderCallbacks = {
 	m_CGDataProviderGetBytesCallback, 	/*  getBytes */
 	m_CGDataProviderSkipBytesCallback,	/*  skipBytes */
 	m_CGDataProviderRewindCallback,		/*  rewind */
 	m_CGDataProviderReleaseInfoCallback	/*  releaseProvider */
 };
+#endif /* PyObjC_BUILD_RELEASE < 1008 */
 
+#if PyObjC_BUILD_RELEASE < 1008
 static const void*
 m_CGDataProviderGetBytePointerCallback(void* _info)
 {
@@ -406,6 +423,7 @@ static CGDataProviderDirectAccessCallbacks m_CGDataProviderDirectAccessCallbacks
 	m_CGDataProviderGetBytesAtOffsetCallback,	/* getBytes */
 	m_CGDataProviderReleaseInfoCallback		/* releaseProvider */
 };
+#endif /* PyObjC_BUILD_RELEASE < 1008 */
 
 
 
@@ -519,6 +537,7 @@ m_CGDataProviderCreateSequential(PyObject* self __attribute__((__unused__)),
 #endif
 
 
+#if PyObjC_BUILD_RELEASE < 1008
 PyDoc_STRVAR(doc_CGDataProviderCreate,
 	"CGDataConsumerCreate(info, (getBytes, skipBytes, rewind, releaseProvider)) -> object\n"
 	"\n"
@@ -672,6 +691,7 @@ m_CGDataProviderCreateDirectAccess(PyObject* self __attribute__((__unused__)),
 	CGDataProviderRelease(result);
 	return retval;
 }
+#endif
 
 /*
  * CGDataProviderCreateWithData
@@ -685,7 +705,7 @@ m_releaseData(void* _info, const void* data, size_t size)
 
 	PyGILState_STATE   state = PyGILState_Ensure();
 
-#if PY_VERSION_MAJOR == 2
+#if PY_MAJOR_VERSION == 2
 	tag = PyInt_AsLong(PyTuple_GET_ITEM(info, 2));
 #else
 	tag = PyLong_AsLong(PyTuple_GET_ITEM(info, 2));
@@ -767,9 +787,7 @@ m_CGDataProviderCreateWithData(PyObject* self __attribute__((__unused__)),
 
 	PyObject* retval = PyObjC_ObjCToPython(
 			@encode(CGDataProviderRef), &result);
-	printf("%s %d\n", __FILE__, __LINE__);
 	CFRelease(result);
-	printf("%s %d\n", __FILE__, __LINE__);
 	return retval;
 }
 
@@ -786,7 +804,7 @@ m_CGFunctionEvaluateCallback(void* _info, const CGFloat* inData, CGFloat* outDat
 
 	PyGILState_STATE   state = PyGILState_Ensure();
 
-#if PY_VERSION_MAJOR == 2
+#if PY_MAJOR_VERSION == 2
 	domdim = PyInt_AsLong(PyTuple_GET_ITEM(info, 2));
 	rangedim = PyInt_AsLong(PyTuple_GET_ITEM(info, 3));
 #else
@@ -2035,6 +2053,7 @@ static PyMethodDef mod_methods[] = {
 		doc_CGDataConsumerCreate
 	},
 
+#if PyObjC_BUILD_RELEASE < 1008
 	{
 		"CGDataProviderCreate",
 		(PyCFunction)m_CGDataProviderCreate,
@@ -2048,6 +2067,7 @@ static PyMethodDef mod_methods[] = {
 		METH_VARARGS,
 		doc_CGDataProviderCreateDirectAccess
 	},
+#endif
 
 #if PyObjC_BUILD_RELEASE >= 1005
 
