@@ -6,7 +6,7 @@ class TestCABase (TestCase):
     @min_os_level('10.5')
     def testFunctions(self):
         v = CACurrentMediaTime()
-        self.failUnlessIsInstance(v, float)
+        self.assertIsInstance(v, float)
 
 if __name__ == "__main__":
     main()
