@@ -1,16 +1,21 @@
 from PyObjCTools.TestSupport import *
 from Quartz import *
 
+try:
+    long
+except NameError:
+    long = int
+
 class TestCVHostTime (TestCase):
     def testFunctions(self):
         v = CVGetCurrentHostTime()
-        self.failUnlessIsInstance(v, (int, long))
+        self.assertIsInstance(v, (int, long))
 
         v = CVGetHostClockFrequency()
-        self.failUnlessIsInstance(v, float)
+        self.assertIsInstance(v, float)
 
         v = CVGetHostClockMinimumTimeDelta()
-        self.failUnlessIsInstance(v, (int, long))
+        self.assertIsInstance(v, (int, long))
 
 if __name__ == "__main__":
     main()
