@@ -2,6 +2,16 @@
 from PyObjCTools.TestSupport import *
 from Quartz import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+
+try:
+    long
+except NameError:
+    long = int
 class TestCVOpenGLBuffer (TestCase):
     def testConstants(self):
         self.assertIsInstance(kCVOpenGLBufferWidth, unicode)
@@ -31,7 +41,7 @@ class TestCVOpenGLBuffer (TestCase):
         self.assertIsInstance(v, CFDictionaryRef)
 
         # FIXME: actual test
-        self.assertArgHasType(CVOpenGLBufferAttach, 0, b'@')
+        self.assertArgHasType(CVOpenGLBufferAttach, 0, b'^{__CVBuffer=}')
 
 if __name__ == "__main__":
     main()
