@@ -2,10 +2,16 @@
 from PyObjCTools.TestSupport import *
 from Quartz import *
 
+try:
+    long
+except NameError:
+    long = int
+
 class TestCVOpenGLTexture (TestCase):
     def testTypes(self):
         self.assertIsCFType(CVOpenGLTextureRef)
 
+    @expectedFailure
     def testFunctions(self):
         self.assertIsInstance(CVOpenGLTextureGetTypeID(), (int, long))
 
