@@ -2,6 +2,11 @@
 from PyObjCTools.TestSupport import *
 from Quartz import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestCVOpenGLTextureCache (TestCase):
     def testTypes(self):
         self.assertIsCFType(CVOpenGLTextureCacheRef)
@@ -12,6 +17,7 @@ class TestCVOpenGLTextureCache (TestCase):
         self.assertIsInstance(kCVOpenGLTextureCacheChromaSamplingModeHighestQuality, unicode)
         self.assertIsInstance(kCVOpenGLTextureCacheChromaSamplingModeBestPerformance, unicode)
 
+    @expectedFailure
     def testFunctions(self):
 
         self.fail("Create CGLContext and CGLFormat")
